@@ -80,12 +80,12 @@ def parse_poly(pstr:str):
     coords = []
     for line in lines:
         line = line.rstrip()
-        swt = line.startswith('\t')
-        print(f'line: {line}, startswith_tab:{swt}, mode:{mode}')
-        if mode == 0 and line.startswith('\t'):
+        line = line.replace('\t',' ')
+        swt = line.startswith(' ')
+        if mode == 0 and swt:
             mode = 1 #begin area
-        if mode == 1 and line.startswith('\t'):
-            items = [float(x) for x in line.split('\t') if len(x)>0]
+        if mode == 1 and swt:
+            items = [float(x) for x in line.split(' ') if len(x)>0]
             if len(items) == 2:
                 coords.append([items[0],items[1]])
             else:
